# project3

A project using the `flat` layout with Odoo addons in `odoo/addons`.

This layout is also simple and installs simply in editable mode. It is however less
accurate than the `src` layout (see `project1`), since unintended python files and
packages in the project root may be imported accidentally.
